==> estateplat-common-1.2.1-20170712.043816-56-sources.jar: cn/gtmap/estateplat/model/server/core/BdcGdRel.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
 * @version 1.0, 2017/6/28
 * @description 不动产供地关系表
 */
@Table(name = "bdc_gd_rel")
public class BdcGdRel {

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 关系id，主键
     */
    @Id
    private String relid;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 不动产单元号
     */
    private String bdcdyh;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 供地合同号
     */
    private String gdhth;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 供地地块ID
     */
    private String gddkid;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 供地项目ID
     */
    private String gdxmid;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 不动产项目ID
     */
    private String bdcxmid;

    public String getRelid() {
        return relid;
    }

    public void setRelid(String relid) {
        this.relid = relid;
    }

    public String getBdcxmid() {
        return bdcxmid;
    }

    public void setBdcxmid(String bdcxmid) {
        this.bdcxmid = bdcxmid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getGdhth() {
        return gdhth;
    }

    public void setGdhth(String gdhth) {
        this.gdhth = gdhth;
    }

    public String getGdxmid() {
        return gdxmid;
    }

    public void setGdxmid(String gdxmid) {
        this.gdxmid = gdxmid;
    }

    public String getGddkid() {
        return gddkid;
    }

    public void setGddkid(String gddkid) {
        this.gddkid = gddkid;
    }
}

==> estateplat-common-1.2.4-20210916.024707-876-sources.jar: cn/gtmap/estateplat/model/server/core/BdcGdRel.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
 * @version 1.0, 2017/6/28
 * @description 不动产供地关系表
 */
@Table(name = "bdc_gd_rel")
public class BdcGdRel {

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 关系id，主键
     */
    @Id
    private String relid;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 不动产单元号
     */
    private String bdcdyh;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 供地合同号
     */
    private String gdhth;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 供地地块ID
     */
    private String gddkid;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 供地项目ID
     */
    private String gdxmid;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 不动产项目ID
     */
    private String bdcxmid;

    /**
     * @author <a href="mailto:zx@gtmap.cn">zx</a>
     * @description 用地批准号
     */
    private String ydpzh;

    public String getRelid() {
        return relid;
    }

    public void setRelid(String relid) {
        this.relid = relid;
    }

    public String getBdcxmid() {
        return bdcxmid;
    }

    public void setBdcxmid(String bdcxmid) {
        this.bdcxmid = bdcxmid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getGdhth() {
        return gdhth;
    }

    public void setGdhth(String gdhth) {
        this.gdhth = gdhth;
    }

    public String getGdxmid() {
        return gdxmid;
    }

    public void setGdxmid(String gdxmid) {
        this.gdxmid = gdxmid;
    }

    public String getGddkid() {
        return gddkid;
    }

    public void setGddkid(String gddkid) {
        this.gddkid = gddkid;
    }

    public String getYdpzh() {
        return ydpzh;
    }

    public void setYdpzh(String ydpzh) {
        this.ydpzh = ydpzh;
    }
}
